import { Url } from './models';
export type PathParamsBuilderOptions = {
    url: Url;
    pathParams: Record<string, unknown>;
};
/**
 * Replaces all the matching keys in the path params in the url with the
 * value. A path param as a placeholder for a value in the url denoted
 * by a colon (:). For example in the following url:
 *
 * `users/:id/:tab?` there are two path params :id and :tab?. A question
 * mark at the end of a path param denotes an optional path param.
 *
 * Optional path params are removed when no value is supplied.
 *
 * @example
 * pathParamsBuilder({url: '/users/:id', pathParams: {id: 1}}) // '/users/1
 * pathParamsBuilder({url: '/users/:id/:tab?', pathParams: {id: 1}}) // '/users/1
 * pathParamsBuilder({url: '/users/:id/:tab?', pathParams: {id: 1, tab: 'profile' }}) // '/users/1/profile
 *
 * @param {String} options.url The url to be parsed
 * @param {Object} options.pathParams Consists of the matching key in the url to be replaced by the value.
 */
export declare function pathParamsBuilder(options: PathParamsBuilderOptions): Url;
