import { Url } from './models';
export type QueryParamsBuilderOptions<QueryParams> = {
    url: Url;
    queryParams: QueryParams;
    defaultQueryParams: QueryParams;
};
/**
 * Takes a URL and query builder options and appends the query parameters
 * to the URL. It ignores query parameters which match the default query
 * parameters.
 *
 * @example
 * queryParamsBuilder({url: 'users/1', queryParams: { visible: true }, { defaultQueryParams: visible: false} }) === '/users/1?visible=true
 *
 * @param {String} options.url The url which get the query parameters appended.
 * @param {Object} options.queryParams The query params as an object.
 * @param {Object} options.defaultQueryParams The default query parameters.
 */
export declare function queryParamsBuilder<QueryParams extends Record<string, unknown>>(options: QueryParamsBuilderOptions<QueryParams>): Url;
